==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/9e/9e82c20389d55ed9a88c0f05d22cca92.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Exception/InvalidEmailException.php */
class __TwigTemplate_f093140c3ea985675d40c4c4d774e727 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Exception;

use Mautic\\CoreBundle\\Exception\\InvalidValueException;

class InvalidEmailException extends InvalidValueException
{
    public function __construct(
        protected string \$emailAddress,
        string \$message = '',
        int \$code = 0,
        ?\\Throwable \$previous = null
    ) {
        parent::__construct(\$message, \$code, \$previous);
    }

    public function getEmailAddress(): string
    {
        return \$this->emailAddress;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Exception/InvalidEmailException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Exception/InvalidEmailException.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Exception/InvalidEmailException.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/9e/9e82c20389d55ed9a88c0f05d22cca92.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Exception/InvalidEmailException.php */
class __TwigTemplate_f093140c3ea985675d40c4c4d774e727 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Exception;

use Mautic\\CoreBundle\\Exception\\InvalidValueException;

class InvalidEmailException extends InvalidValueException
{
    public function __construct(
        protected string \$emailAddress,
        string \$message = '',
        int \$code = 0,
        ?\\Throwable \$previous = null
    ) {
        parent::__construct(\$message, \$code, \$previous);
    }

    public function getEmailAddress(): string
    {
        return \$this->emailAddress;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Exception/InvalidEmailException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Exception/InvalidEmailException.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Exception/InvalidEmailException.php");
    }
}
